@@ -28,6 +28,7 @@ from .merge_request_approvals import (  # noqa: F401
     ProjectMergeRequestApprovalRuleManager,
 )
 from .notes import ProjectMergeRequestNoteManager  # noqa: F401
+from .pipelines import ProjectMergeRequestPipelineManager  # noqa: F401
 
 __all__ = [
     "MergeRequest",
@@ -145,6 +146,7 @@ class ProjectMergeRequest(
         ("diffs", "ProjectMergeRequestDiffManager"),
         ("discussions", "ProjectMergeRequestDiscussionManager"),
         ("notes", "ProjectMergeRequestNoteManager"),
+        ("pipelines", "ProjectMergeRequestPipelineManager"),
         ("resourcelabelevents", "ProjectMergeRequestResourceLabelEventManager"),
         ("resourcemilestoneevents", "ProjectMergeRequestResourceMilestoneEventManager"),
         ("resourcestateevents", "ProjectMergeRequestResourceStateEventManager"),
@@ -240,25 +242,6 @@ class ProjectMergeRequest(
         path = "%s/%s/changes" % (self.manager.path, self.get_id())
         return self.manager.gitlab.http_get(path, **kwargs)
 
-    @cli.register_custom_action("ProjectMergeRequest")
-    @exc.on_http_error(exc.GitlabListError)
-    def pipelines(self, **kwargs):
-        """List the merge request pipelines.
-
-        Args:
-            **kwargs: Extra options to send to the server (e.g. sudo)
-
-        Raises:
-            GitlabAuthenticationError: If authentication is not correct
-            GitlabListError: If the list could not be retrieved
-
-        Returns:
-            RESTObjectList: List of changes
-        """
-
-        path = "%s/%s/pipelines" % (self.manager.path, self.get_id())
-        return self.manager.gitlab.http_get(path, **kwargs)
-
     @cli.register_custom_action("ProjectMergeRequest", tuple(), ("sha",))
     @exc.on_http_error(exc.GitlabMRApprovalError)
     def approve(self, sha=None, **kwargs):
@@ -373,6 +356,7 @@ class ProjectMergeRequestManager(CRUDMixin, RESTManager):
             "remove_source_branch",
             "allow_maintainer_to_push",
             "squash",
+            "reviewer_ids",
         ),
     )
     _update_attrs = RequiredOptional(
@@ -388,6 +372,7 @@ class ProjectMergeRequestManager(CRUDMixin, RESTManager):
             "discussion_locked",
             "allow_maintainer_to_push",
             "squash",
+            "reviewer_ids",
         ),
     )
     _list_filters = (
